@@ -1,4 +1,4 @@
-/*! Widget: scroller - updated 4/18/2017 (v2.28.8) *//*
+/*! Widget: scroller - updated 12/13/2017 (v2.29.1) *//*
 	Copyright (C) 2011 T. Connell & Associates, Inc.
 
 	Dual-licensed under the MIT and GPL licenses
@@ -273,6 +273,9 @@
 			$tableWrap
 				.off( 'scroll' + namespace )
 				.on( 'scroll' + namespace, function() {
+					// Save position
+					wo.scroller_saved[0] = $tableWrap.scrollLeft();
+					wo.scroller_saved[1] = $tableWrap.scrollTop();
 					if ( wo.scroller_jumpToHeader ) {
 						var pos = $win.scrollTop() - $hdr.offset().top;
 						if ( $( this ).scrollTop() !== 0 && pos < tbHt && pos > 0 ) {
@@ -286,8 +289,10 @@
 				});
 
 			// resize/update events - filterEnd fires after "tablesorter-initialized" and "updateComplete"
-			events = ( ( ts.hasWidget( c.table, 'filter' ) ? 'filterEnd' : 'tablesorter-initialized updateComplete' ) +
-					' sortEnd pagerComplete columnUpdate ' ).split( ' ' ).join( namespace + ' ' );
+			tmp = ts.hasWidget( c.table, 'filter' ) ?
+				'filterEnd filterInit' :
+				'tablesorter-initialized updateComplete';
+			events = ( tmp + ' sortEnd pagerComplete columnUpdate ' ).split( ' ' ).join( namespace + ' ' );
 
 			$table
 				.off( namespace )
@@ -841,6 +846,7 @@
 			// adjust caption height, see #1202
 			$fixedColumn.find('caption').height( wo.scroller_$header.find( 'caption' ).height() );
 
+			$tableWrap.scroll();
 			wo.scroller_isBusy = false;
 
 		},
